# Calculation of the head loss on a water intake grid

<div style="position: relative"><a id="grille-conventionnelle" style="position: absolute; top: -60px;"></a></div>
## Conventional grid

Conventional grid planes: perpendicular to the flow and slightly inclined to the horizontal

### Formula

Use of the F1 formula of Raynal et al (2012) to calculate the head losses.

$$\xi = K_F * K_O * K_\beta = a * \left ( \frac{O}{1-O} \right )^{1.6} * \left ( 1 - \cos{\beta} \right )^{0.39}$$


<div style="position: relative"><a id="grille-orientee" style="position: absolute; top: -60px;"></a></div>
## Oriented grid

Flow-oriented and near-vertical grid planes.

![Oriented grid](grille-orientee.jpg)

*Courret, D. et Larinier, M. Guide pour la conception de prise d’eau ichtyocompatibles pour les petites centrales hydroélectriques, 2008. <https://doi.org/10.13140/RG.2.1.2359.1449>.*

### Formula

Use of the F2 formula of Raynal et al (2012) to calculate the head losses.

$$\xi = K_F * K_O * K_\alpha = a * \left ( \frac{O}{1-O} \right )^{1.6} * \left ( 1 + c * \left ( \frac{90 - \alpha}{90} \right )^{2.35} * \left ( \frac{1 - O}{O} \right )^{3} \right )$$


<div style="position: relative"><a id="grille-inclinee" style="position: absolute; top: -60px;"></a></div>
## Inclined grid

Grid planes perpendicular to the flow, and inclined with respect to the horizontal

![Inclined grid](grille-inclinee.jpg)

![Inclined grid](grille-inclinee-b.jpg)

*Courret, D. et Larinier, M. Guide pour la conception de prise d’eau ichtyocompatibles pour les petites centrales hydroélectriques, 2008. <https://doi.org/10.13140/RG.2.1.2359.1449>.*

### Formula

Use of the F3 formula of Raynal et al (2012) to calculate the head losses.

$$\xi = K_{F, b} * K_b * K_\beta + K_{Fent} * K_{entH} = a * \left ( \frac{O_b}{1-O_b} \right )^{1.65} * \left ( \sin \beta \right )^{2} + c * \left ( \frac{O_{entH}}{1-O_{entH}} \right )^{0.77}$$



## Parameters

<div style="position: relative"><a id="cote-du-sommet-immerge-du-plan-de-grille" style="position: absolute; top: -60px;"></a></div>
### Elevation of the immersed vertex of the grid plane

May be different from the water level if the top of the grid plane is drowned.

<div style="position: relative"><a id="largeur-de-la-section" style="position: absolute; top: -60px;"></a></div>
### Section width

#### Conventional or inclined grid

Must also correspond to the width of the grid plane.

<div style="position: relative"><a id="vitesse-dapproche-moyenne-pour-le-debit-maximum-turbine-en-soustrayant-la-partie-superieure-eventuellement-obturee" style="position: absolute; top: -60px;"></a></div>
### Average approach speed for the maximum turbinated flow, subtracting the upper part, if any, blocked

"Maximum" value of the approach speed taken into account in the calculation of the head loss in a safety approach.

<div style="position: relative"><a id="inclinaison-par-rapport-a-lhorizontale" style="position: absolute; top: -60px;"></a></div>
### Inclination with respect to the horizontal

#### Conventional grid

Scope of the formula: 45 ≤ β ≤ 90°

#### Oriented grid

Vertical grid planes (β = 90°).

The slight inclination of the grid planes (β≈ 75/80°), often set up for screening purposes, can be neglected.

#### inclined grid

Scope of the formula: 15° ≤ β ≤ 90°
Recommended for fish guidance: β ≤ 26°

<div style="position: relative"><a id="orientation-par-rapport-a-la-direction-de-lecoulement" style="position: absolute; top: -60px;"></a></div>
### Orientation with respect to the direction of flow

#### Conventional grid

Grid planes perpendicular to the flow (α = 90°)

#### Oriented grid

Scope of the formula: 30° ≤ α ≤ 90°

Recommended for fish guidance: α ≤ 45°

#### inclined grid

Grid planes perpendicular to the flow (α = 90°)

<div style="position: relative"><a id="vitesse-normale-moyenne-pour-le-debit-maximum-turbine" style="position: absolute; top: -60px;"></a></div>
### Average normal speed for maximum turbinated flow rate

#### Conventional grid

Recommended to avoid plating fish on the grid plane (physical barrier) or their premature passage through (behavioural barrier): VN ≤ 0.5 m/s.

#### Oriented or inclined grid

Recommended to avoid plating fish on the grid plane (physical barrier) or their premature passage through (behavioural barrier): VN ≤ 0.5 m/s.

Above the average value calculated here, it is essential to refer to the recommendations derived from the experimental characterization of the actual velocity values.

<div style="position: relative"><a id="rapport-de-forme-des-barreaux" style="position: absolute; top: -60px;"></a></div>
### Bar shape ratio

#### Oriented grid

Validity range of the formula: ratio b / p close to 0.125

<div style="position: relative"><a id="rapport-espacementepaisseur-des-barreaux" style="position: absolute; top: -60px;"></a></div>
### Ratio of spacing / bar thickness

#### Oriented grid

Scope of validity of the formula: 1 ≤ e / b ≤ 3

<div style="position: relative"><a id="obstruction-globale-du-plan-de-grille-barreaux-entretoises-elements-de-supports-longitudinaux-et-transversaux-retenue" style="position: absolute; top: -60px;"></a></div>
### Overall obstruction of the grid plane (bars + spacers + longitudinal and transverse support elements) retained

To be determined from the grid plans.

#### Conventional grid

Scope of validity of the formula: 0.2 ≤ O ≤ 0.60

#### Oriented grid

Scope of the formula: 0.35 ≤ O ≤ 0.60

#### inclined grid

Obstruction due to the bars and longitudinal support elements retained \(O_b\). To be determined from the grid plans.

Scope of validity of the formula: 0.28 ≤ Ob ≤ 0.53

<div style="position: relative"><a id="profil-des-barreaux" style="position: absolute; top: -60px;"></a></div>
### Bar profile

![Bar profile](profil-barreaux.png)

*Raynal, Sylvain. « Étude expérimentale et numérique des grilles ichtyocompatibles ». Sciences et ingénierie en matériaux, mécanique, énergétique et aéronautique - SIMMEA, 2013.*

#### Conventional grid

The shape coefficient of the bars \(a\) is 2.89 for the rectangular profile (PR) and 1.70 for the hydrodynamic profile (PH).

#### Oriented grid

The shape coefficient of the bars is 2.89 for the rectangular profile (PR) and 1.70 for the hydrodynamic profile (PH).

The shape coefficient of the bars \(c\) is 1.69 for the rectangular profile (PR) and 2.78 for the hydrodynamic profile (PH).

#### inclined grid

The shape coefficient of the bars \(a\) is 3.85 for the rectangular profile (PR) and 2.10 for the hydrodynamic profile (PH).

<div style="position: relative"><a id="obstruction-effective-due-aux-entretoises-et-elements-de-support-transversaux-rapportee-a-la-section-decoulement" style="position: absolute; top: -60px;"></a></div>
### Effective obstruction due to spacers and transverse support elements in relation to the flow cross-section

#### inclined grid

To be determined from the grid plans.
Scope of the formula: OentH ≤ 0.28

<div style="position: relative"><a id="coefficient-de-forme-moyen-des-entretoises-et-elements-transversaux-ponderes-selon-leurs-parts-respectives" style="position: absolute; top: -60px;"></a></div>
### Average shape coefficient of spacers and transverse elements, weighted according to their respective shares

#### inclined grid

To be determined from the grid plans.

For example, 1.79 for cylindrical spacers, 2.42 for rectangular spacers, and around 4 for square beams and IPNs.
